dfir_syntax!() { /* proc-macro */ }Expand description
Create a runnable graph instance using DFIR’s custom syntax.
For example usage, take a look at the surface_* tests in the tests folder
or the examples folder
in the Hydro repo.
dfir_syntax!() { /* proc-macro */ }Create a runnable graph instance using DFIR’s custom syntax.
For example usage, take a look at the surface_* tests in the tests folder
or the examples folder
in the Hydro repo.